@@ -439,7 +439,8 @@ CIFPaintWirePath(
 		/* Wire reverses direction.  Break wire here,	*/
 		/* draw, and start new polygon.			*/
 
-		TxError("Warning: direction reversal in path.\n");
+		TxError("Warning: direction reversal in path at (%d, %d).\n",
+				pathp->cifp_x, pathp->cifp_y);
 
 		phi = theta;
 		if (endcap)
@@ -451,7 +452,8 @@ CIFPaintWirePath(
 		firstpoint = TRUE;
 	    }
 	    else {
-		TxError("Error: mitre limit exceeded at wire junction.\n");
+		TxError("Error: mitre limit exceeded at wire junction at (%d, %d).\n",
+				pathp->cifp_x, pathp->cifp_y);
 		TxError("Route has been truncated.\n");
 		break;
 	   }
@@ -687,7 +689,8 @@ CIFParseWire(void)
 
     width /= cifReadScale2;
     savescale = cifReadScale1;
-    if (!CIFParsePath(&pathheadp, 2))
+    pathheadp = CIFParsePath(2);
+    if (pathheadp == NULL)
     {
 	CIFReadError("wire, but improper path; ignored.\n");
 	CIFSkipToSemi();
@@ -797,7 +800,8 @@ CIFParsePoly(void)
 	CIFSkipToSemi();
 	return FALSE;
     }
-    if (!CIFParsePath(&pathheadp, 1))
+    pathheadp = CIFParsePath(1);
+    if (pathheadp == NULL)
     {
 	CIFReadError("polygon, but improper path; ignored.\n");
 	CIFSkipToSemi();
