@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cmwind/CMWmain.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cmwind/CMWmain.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -44,12 +44,12 @@ global WindClient CMWclientID;
 
 /* Forward and external declarations */
 
-extern void cmwColor();
-extern void cmwSave();
-extern void cmwLoad();
-extern void cmwPushbutton();
-extern void RGBxHSV();
-extern void CMWundoInit();
+extern void cmwColor(MagWindow *w, TxCommand *cmd);
+extern void cmwSave(MagWindow *w, TxCommand *cmd);
+extern void cmwLoad(MagWindow *w, TxCommand *cmd);
+extern void cmwPushbutton(MagWindow *w, TxCommand *cmd);
+extern bool RGBxHSV(double r, double g, double b, double *h, double *s, double *v);
+extern void CMWundoInit(void);
 
 /* -------------------------------------------------------------------- */
 
@@ -89,7 +89,7 @@ extern void CMWundoInit();
  * which pump is hit and which mouse button is used to hit it.
  */
 
-ColorBar colorBars[] =
+const ColorBar colorBars[] =
 {
     {"Red",	CB_RED,		STYLE_RED,	{{ 2000,	8000},	{10000,	 9000}},
 						{{ 2000,	9500},	{10000,	10500}}},
@@ -106,7 +106,7 @@ ColorBar colorBars[] =
     {0}
 };
 
-ColorPump colorPumps[] =
+const ColorPump colorPumps[] =
 {
     {CB_RED,	-.0078,	{{  500, 8000},	{ 1500,	9000}}},
     {CB_RED,	 .0078,	{{10500, 8000},	{11500,	9000}}},
@@ -123,13 +123,13 @@ ColorPump colorPumps[] =
     {-1}
 };
 
-Rect cmwCurrentColorArea = {{6000, 12000}, {18000, 15000}};
-Rect cmwCurrentColorTextBox = {{6000, 15500}, {18000, 16500}};
-char *cmwCurrentColorText = "Color Being Edited";
+const Rect cmwCurrentColorArea = {{6000, 12000}, {18000, 15000}};
+const Rect cmwCurrentColorTextBox = {{6000, 15500}, {18000, 16500}};
+const char * const cmwCurrentColorText = "Color Being Edited";
 
 /* Bounding rectangle for entire window */
 
-Rect colorWindowRect = {{0, 1500}, {24000, 17000}};
+const Rect colorWindowRect = {{0, 1500}, {24000, 17000}};
 
 /*
  * ----------------------------------------------------------------------------
@@ -149,13 +149,13 @@ Rect colorWindowRect = {{0, 1500}, {24000, 17000}};
  */
 
 bool
-CMWcreate(window, argc, argv)
-    MagWindow *window;
-    int argc;
-    char *argv[];
+CMWcreate(
+    MagWindow *window,
+    int argc,
+    char *argv[])
 {
     CMWclientRec *crec;
-    int color;
+    unsigned int color;
 
     crec = (CMWclientRec *) mallocMagic(sizeof(CMWclientRec));
     window->w_clientData = (ClientData) crec;
@@ -189,8 +189,8 @@ CMWcreate(window, argc, argv)
  */
 
 bool
-CMWdelete(window)
-    MagWindow *window;
+CMWdelete(
+    MagWindow *window)
 {
     CMWclientRec *cr;
 
@@ -218,10 +218,10 @@ CMWdelete(window)
  */
 
 void
-CMWreposition(window, newScreenArea, final)
-    MagWindow *window;
-    Rect *newScreenArea;
-    bool final;
+CMWreposition(
+    MagWindow *window,
+    Rect *newScreenArea,
+    bool final)
 {
     if (final)
 	WindMove(window, &colorWindowRect);
@@ -244,14 +244,14 @@ CMWreposition(window, newScreenArea, final)
  */
 
 void
-CMWredisplay(w, rootArea, clipArea)
-    MagWindow *w;		/* The window containing the area. */
-    Rect *rootArea;	/* Redisplay area in surface coordinates. */
-    Rect *clipArea;	/* An area on the screen to clip to. */
+CMWredisplay(
+    MagWindow *w,		/* The window containing the area. */
+    Rect *rootArea,	/* Redisplay area in surface coordinates. */
+    Rect *clipArea)	/* An area on the screen to clip to. */
 {
     CMWclientRec *cr;
-    ColorBar *cb;
-    ColorPump *cp;
+    const ColorBar *cb;
+    const ColorPump *cp;
     Rect rect, screenR;
     Point screenP;
     double values[6], x;
@@ -372,9 +372,9 @@ CMWredisplay(w, rootArea, clipArea)
  */
 
 void
-CMWloadWindow(w, color)
-    MagWindow *w;	/* Identifies window to which color is to be bound */
-    int color;		/* New color to be bound to this window. */
+CMWloadWindow(
+    MagWindow *w,	/* Identifies window to which color is to be bound */
+    int color)		/* New color to be bound to this window. */
 {
     CMWclientRec *cr = (CMWclientRec *) w->w_clientData;
     char caption[40];
@@ -407,7 +407,7 @@ CMWloadWindow(w, color)
  */
 
 void
-CMWinit()
+CMWinit(void)
 {
     CMWclientID = WindAddClient("color", CMWcreate, CMWdelete,
 			CMWredisplay, CMWcommand,
