@@ -14,12 +14,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 #include <X11/Xlib.h>
 #include <X11/keysym.h>
 #include <X11/Xutil.h>
 
-/* 
+/*
  * Portability stuff
  */
 
@@ -28,7 +30,7 @@
 #endif
 
 /* Some machines have signal handlers returning an int, while other machines
- * have it returning a void.  If you have a machine that requires ints put 
+ * have it returning a void.  If you have a machine that requires ints put
  * it in the list of machines in utils/magic.h.
  */
 #ifdef	SIG_RETURNS_INT
@@ -91,7 +93,7 @@ main (argc, argv)
 
 /*     sigSetAction(SIGINT,  SIG_IGN); */
 /*     sigSetAction(SIGQUIT, SIG_IGN); */
-    sigSetAction(SIGTERM, MapWindow); 
+    sigSetAction(SIGTERM, MapWindow);
 #ifdef SIGTSTP
     sigSetAction(SIGTSTP, SIG_IGN);
 #endif
@@ -113,7 +115,7 @@ main (argc, argv)
  *   Pass XEvents on to the magic main process by writing into the
  *   connecting pipe.  Keystrokes must be handled such that magic
  *   can treat untranslated keyboard input from stdin the same way
- *   that it treats translated keyboard input through X11.  
+ *   that it treats translated keyboard input through X11.
  *   Use XLookupString() to get an ASCII character out of the
  *   keycode, but also pass back the event structure so we can
  *   pull out key modifier information in grX11Stdin().
@@ -127,7 +129,7 @@ void
 ParseEvent (event)
     XEvent *event;
 {
-    if (event->type == KeyPress) 
+    if (event->type == KeyPress)
     {
 	XKeyPressedEvent *KeyPressedEvent = (XKeyPressedEvent *) event;
 	char inChar[10], c, *p;
@@ -143,7 +145,7 @@ ParseEvent (event)
 	keymod = (LockMask | ControlMask | ShiftMask)
 				& KeyPressedEvent->state;
 
-#ifdef macosx
+#ifdef __APPLE__
 	if (KeyPressedEvent->state & (Mod1Mask | Mod2Mask | Mod3Mask
 				| Mod4Mask | Mod5Mask))
 	    keymod |= Mod1Mask;
@@ -193,7 +195,7 @@ ParseEvent (event)
 		if ((c = *p++) == 3)	/* Ctrl-C interrupt */
 		{
 		    kill(parentID, SIGINT);
-		} 
+		}
 		else
 		{
 		    /* When Control modifier is present, use the capital */
@@ -279,7 +281,7 @@ TimeOut(int signo)
     }
     SetTimeOut(); 	/* Renew the timer and signal handler */
 }
- 
+
 /*
  * MapWindow():
  *   On startup of any new magic window, magic writes the X11 window ID
